==> dde-file-manager_5.2.18.orig.tar.xz: dde-file-manager-5.2.18/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_sr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sr" version="2.1">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>Време за идентификацију је истекло</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Диск је у употреби, тренутно се не може демонтирати</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Диск је у употреби, тренутно се не може избацити</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>Уређај је заузет, не може се избацити</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>Уређај је заузет, не може се уклонити</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 Логички диск</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Непознато</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Уређај није безбедно уклоњен</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Следећи пут, кликните на &quot;Безбедно уклони&quot;, затим уклоните уређај</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation type="vanished">Уређај је заузет, не може се избацити</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation type="vanished">Уређај је заузет, не може се уклонити</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Не могу да демонтирам уређај</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>Диск је монтирао корисник &quot;%1&quot;, не можете га демонтирати.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Не могу да пронађем монтирани уређај</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Дискови</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Диск</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Отвори</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Избаци све</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>Уређај је безбедно уклоњен</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Забрањен приступ</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>Немате дозволу да приступите овој фасцикли</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Потврди</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Проверавање уређаја, зауставити?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Заустави</translation>
    </message>
</context>
</TS>

==> dde-file-manager_5.8.1.orig.tar.xz: dde-file-manager-5.8.1/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_sr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sr">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>Време за идентификацију је истекло</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Диск је у употреби, тренутно се не може демонтирати</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Диск је у употреби, тренутно се не може избацити</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>Уређај је заузет, не може се избацити</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>Уређај је заузет, не може се уклонити</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 Логички диск</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Непознато</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Уређај није безбедно уклоњен</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Следећи пут, кликните на &quot;Безбедно уклони&quot;, затим уклоните уређај</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Не могу да демонтирам уређај</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>Диск је монтирао корисник &quot;%1&quot;, не можете га демонтирати.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Не могу да пронађем монтирани уређај</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Дискови</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Диск</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Отвори</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Избаци све</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>Уређај је безбедно уклоњен</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Забрањен приступ</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>Немате дозволу да приступите овој фасцикли</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Проверавање уређаја, зауставити?</translation>
    </message>
    <message>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Потврди</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Откажи</translation>
    </message>
    <message>
        <source>Stop</source>
        <comment>button</comment>
        <translation>Заустави</translation>
    </message>
</context>
</TS>
